@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import os
 import re
-import shutil
 import sys
 
 from contextlib import suppress
@@ -30,6 +29,7 @@ from cleo.io.inputs.option import Option
 from cleo.io.io import IO
 from cleo.io.outputs.output import Verbosity
 from cleo.io.outputs.stream_output import StreamOutput
+from cleo.terminal import Terminal
 from cleo.ui.ui import UI
 
 
@@ -61,7 +61,7 @@ class Application:
         self._name = name
         self._version = version
         self._display_name: str | None = None
-        self._terminal = shutil.get_terminal_size()
+        self._terminal = Terminal().size
         self._default_command = "list"
         self._single_command = False
         self._commands: dict[str, Command] = {}
@@ -420,7 +420,7 @@ class Application:
                     break
 
             if index is not None:
-                del argv[index + 1 : index + 1 + (len(name.split(" ")) - 1)]
+                del argv[index + 1 : index + 1 + name.count(" ")]
 
             stream = io.input.stream
             interactive = io.input.is_interactive()
@@ -614,11 +614,7 @@ class Application:
 
     def extract_namespace(self, name: str, limit: int | None = None) -> str:
         parts = name.split(" ")[:-1]
-
-        if limit is not None:
-            return " ".join(parts[:limit])
-
-        return " ".join(parts)
+        return " ".join(parts[:limit])
 
     def _get_default_ui(self) -> UI:
         from cleo.ui.progress_bar import ProgressBar
@@ -631,10 +627,7 @@ class Application:
         namespaces: list[str] = []
 
         for part in parts:
-            if namespaces:
-                namespaces.append(namespaces[-1] + " " + part)
-            else:
-                namespaces.append(part)
+            namespaces.append(namespaces[-1] + " " + part if namespaces else part)
 
         return namespaces
 
